# -*- coding: UTF-8 -*-
""" A python wrapper for making calls to the Airgram API """

__author__ = "d01"
__email__ = "jungflor@gmail.com"
__copyright__ = "Copyright (C) 2015, Florian JUNG"
__license__ = "MIT"
__version__ = "0.1.2"
__date__ = "2015-08-21"
# Created: 2015-07-30 04:42

from .ag import Airgram, AirgramException



#!/usr/bin/env python
# -*- coding: UTF-8 -*-

from setuptools import setup

def get_version():
    import os
    import re
    version_file = os.path.join("airgram", "__init__.py")
    initfile_lines = open(version_file, 'rt').readlines()
    version_reg = r"^__version__ = ['\"]([^'\"]*)['\"]"
    for line in initfile_lines:
        mo = re.search(version_reg, line, re.M)
        if mo:
            return mo.group(1)
    raise RuntimeError(
        u"Unable to find version string in {}".format(version_file)
    )


def get_file(path):
    with open(path, 'r') as f:
        return f.read()

version = get_version()
requirements = get_file("requirements.txt").split("\n")
readme = get_file("README.rst")
history = get_file("HISTORY.rst")

setup(
    name="airgram",
    version=version,
    description="Wrapper for the airgram api",
    long_description=readme + "\n\n" + history,
    author="d01",
    author_email="jungflor@gmail.com",
    url="https://github.com/the01/python-airgram",
    packages=[
        "airgram"
    ],
    install_requires=requirements,
    license="MIT License",
    keywords="airgram",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
    ]
)



# -*- coding: UTF-8 -*-
""" API access object """

__author__ = "d01"
__email__ = "jungflor@gmail.com"
__copyright__ = "Copyright (C) 2015, Florian JUNG"
__license__ = "MIT"
__version__ = "0.1.2a0"
__date__ = "2015-08-21"
# Created: 2015-07-30 04:44

import logging

import requests

logger = logging.getLogger(__name__)
api_url = "https://api.airgramapp.com/1/"


class AirgramException(Exception):
    """ Custom airgram exception """
    pass


class Airgram(object):
    """ Wrapper class to make calls to http://www.airgramapp.com/api """
    _logger = logging.getLogger(__name__ + ".Airgram")

    def __init__(self, key=None, secret=None, verify_certs=True):
        """
        Initialize object

        :param key: Service key
        :type key: None | str
        :param secret: Service secret
        :type secret: None | str
        :param verify_certs: Verify the certificates when making a request
        :type verify_certs: bool
        :rtype: None
        """
        self.session = requests.Session()
        if key is not None:
            self.session.auth = (key, secret)
        self.verify_certs = verify_certs

    def _request(self, method, email=None, msg=None, url=None):
        """
        Make request to airgram api

        :param method: Which method to invoke on the api
        :type method: None | str
        :param email: email parameter
        :type email: None | str
        :param msg: msg parameter
        :type msg: None | str
        :param url: url parameter
        :type url: None | str
        :return: Response from server
        :rtype: dict
        :raises AirgramException: On failure
        """
        parameter = {}
        if email:
            parameter['email'] = email
        if msg:
            parameter['msg'] = msg
        if url:
            parameter['url'] = url
        try:
            resp = self.session.get(
                api_url + method, params=parameter, verify=self.verify_certs
            )
            resp.raise_for_status()
            return resp.json()
        except Exception as e:
            raise AirgramException(e)

    def send_as_guest(self, email, msg, url=None):
        """
        Sends an Airgram message to a user who already has the Airgram app

        :param email: Email address of the Airgram account you want to message
        :type email: str
        :param msg: Text of the message
        :type msg: str
        :param url: URL to open when the recipient opens the message
            (default: None) if None -> no url
        :type url: None | str
        :return: Response from server
        :rtype: dict
        :raises AirgramException: On failure
        """
        return self._request("send_as_guest", email, msg, url)

    def subscribe(self, email):
        """
        Subscribes an email address to the authenticated Airgram service

        :param email: Email address to subscribe
        :type email: str
        :return: Response from server
        :rtype: dict
        :raises AirgramException: On failure
        """
        return self._request("subscrube", email)

    def send(self, email, msg, url=None):
        """
        Sends an Airgram message to a subscriber of the
        authenticated Airgram service

        :param email: Email address of the subscriber you want to message
        :type email: str
        :param msg: Text of the message
        :type msg: str
        :param url: URL to open when the recipient opens the message
            (default: None) if None -> no url
        :type url: None | str
        :return: Response from server
        :rtype: dict
        :raises AirgramException: On failure
        """
        return self._request("send", email, msg, url)

    def broadcast(self, msg, url=None):
        """
        Sends an Airgram message to all subscribers of the
        authenticated Airgram service

        :param msg: Text of the message
        :type msg: str
        :param url: URL to open when the recipient opens the message
            (default: None) if None -> no url
        :type url: None | str
        :return: Response from server
        :rtype: dict
        :raises AirgramException: On failure
        """
        return self._request("send", None, msg, url)
